
__title__ = 'fastposter'
__description__ = 'Python client for fastposter cloud.'
__url__ = 'https://cloud.fastposter.net/doc/'
__version__ = '1.1.7'
__author__ = 'Alex'
__author_email__ = 'service@fastposter.net'
__license__ = 'MIT'
__copyright__ = 'Copyright 2023 fastposter.net'

